package
Version:
v0.3.14
Opens a new window with list of versions in this module.
Published: Feb 15, 2026
License: Apache-2.0
Opens a new window with license information.
Imports: 4
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
NewCache creates a new cache with a TTL (time-to-live)
Delete removes an item from the cache
Get retrieves an item from the cache
Set adds an item to the cache
type CacheItem struct {
Value interface{}
Expiration time.Time
}
Source Files
¶
Click to show internal directories.
Click to hide internal directories.