security

package
v0.2.74 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jan 25, 2026 License: Apache-2.0 Imports: 9 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AuthnAndAuthz

func AuthnAndAuthz(r *http.Request, operation string) error

AuthnAndAuthz performs authentication and authorization for the given HTTP request and operation.

func AuthnWithAdminCredentials added in v0.2.72

func AuthnWithAdminCredentials(r *http.Request) error

AuthnWithAdminCredentials performs authentication using admin credentials from the request.

Types

This section is empty.

Jump to