Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func AuthnAndAuthz ¶
AuthnAndAuthz performs authentication and authorization for the given HTTP request and operation.
func AuthnWithAdminCredentials ¶ added in v0.2.72
AuthnWithAdminCredentials performs authentication using admin credentials from the request.
Types ¶
This section is empty.
Click to show internal directories.
Click to hide internal directories.